[GRASS-SVN] r60530 - grass-addons/grass7/raster/r.hypso

svn_grass at osgeo.org svn_grass at osgeo.org
Wed May 28 01:30:39 PDT 2014


Author: hellik
Date: 2014-05-28 01:30:38 -0700 (Wed, 28 May 2014)
New Revision: 60530

Modified:
   grass-addons/grass7/raster/r.hypso/r.hypso.py
Log:
r.hypso: ipso -> hypso

Modified: grass-addons/grass7/raster/r.hypso/r.hypso.py
===================================================================
--- grass-addons/grass7/raster/r.hypso/r.hypso.py	2014-05-28 08:20:16 UTC (rev 60529)
+++ grass-addons/grass7/raster/r.hypso/r.hypso.py	2014-05-28 08:30:38 UTC (rev 60530)
@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 ################################################################################
 #
-# MODULE:       r.ipso.py
+# MODULE:       r.hypso.py
 #
 # AUTHOR(S):    Margherita Di Leo, Massimo Di Stefano, Francesco Di Stefano
 #               
 #
 # PURPOSE:      Output a Ipsometric and ipsographic graph 
 #
 # COPYRIGHT:    (c) 2010 Margherita Di Leo, Massimo Di Stefano, Francesco Di Stefano
 #
@@ -20,7 +20,7 @@
 #
 ################################################################################
 #%module
-#% description: Outputs a ipsometric and ipsographic graph.
+#% description: Outputs a hypsometric and hypsographic graph.
 #% keywords: raster
 #%end
 
@@ -38,12 +38,12 @@
 
 #%flag
 #% key: a
-#% description: Generate ipsometric curve
+#% description: Generate hypsometric curve
 #%end
 
 #%flag
 #% key: b
-#% description: Generate ipsographic curve
+#% description: Generate hypsographic curve
 #%end
 
 import sys
@@ -94,12 +94,12 @@
 
     # Managing flag & plot
     if flags['a']:
-        plotImage(zn[:,3], zn[:,5],options['image']+'_Ipsometric.png','-','A(i) / A','Z(i) / Zmax','Ipsometric Curve')
+        plotImage(zn[:,3], zn[:,5],options['image']+'_Hypsometric.png','-','A(i) / A','Z(i) / Zmax','Hypsometric Curve')
     if flags['b']:
-        plotImage(zn[:,4], zn[:,0],options['image']+'_Ipsographic.png','-','A [km^2]','Z [m.slm]','Ipsographic Curve')
+        plotImage(zn[:,4], zn[:,0],options['image']+'_Hypsographic.png','-','A [km^2]','Z [m.slm]','Hypsographic Curve')
 
     print "==========================="
-    print "Ipsometric | quantiles"
+    print "Hypsometric | quantiles"
     print "==========================="
     print '%.0f' %findint(kl,0.025) , "|", 0.025
     print '%.0f' %findint(kl,0.05) , "|", 0.05
@@ -1,12 +1,12 @@
 #               
 #
-# PURPOSE:      Output a Ipsometric and ipsographic graph 
+# PURPOSE:      Output a hypsometric and hypsographic graph 
 #
 # COPYRIGHT:    (c) 2010 Margherita Di Leo, Massimo Di Stefano, Francesco Di Stefano



More information about the grass-commit mailing list